from urllib import request, parse
import json

# query string の準備
params = {
    "state": "closed",
    "labels": "トラブルシューティング"
}
query_string = parse.urlencode(params)

# GET リクエストをするURLを生成
url = "https://api.github.com"
api_path = "/repos/laughk/archlinux-note/issues"
endpoint = f"{url}{api_path}?{query_string}"

# リクエストヘッダ情報
headers = {
    "Accept": "application/vnd.github.v3+json"
}

# Request オブジェクトを用意
req = request.Request(endpoint, headers=headers)

# レスポンスを result で受け取る
result = ""
with request.urlopen(req) as res:
    result = res.read().decode("utf-8")

# result(JSON文字列）をPythonで扱えるデータに変換
issues = json.loads(result)

# 出力するデータに厳選する
output = []
for issue in issues:
    # issue に含まれる title, url, author 情報のみを出力するデータに利用する
    output.append({
        "title": issue["title"],
        "url": issue["html_url"],
        "author": issue["user"]["login"]
    })

# 結果を整形された JSON で表示
print(json.dumps(output, indent=2, ensure_ascii=False))